@@ -32,9 +32,7 @@ class SQLA(SQLAlchemy):
     """
     def make_declarative_base(self, metadata=None):
         """Creates the declarative base."""
-        base = declarative_base(cls=Model, name='Model',
-                                metadata=metadata,
-                                metaclass=ModelDeclarativeMeta)
+        base = Model
         base.query = _QueryProperty(self)
         return base
 
@@ -84,7 +82,7 @@ class Model(object):
             result[key] = col
         return result
 
-    
+
 
 """
     This is for retro compatibility
